@@ -100,14 +100,15 @@ thresholdtime: tolerance for veto in time
 """
 class ClassificationScore:
     
-    def __init__(self, predictions, 
-                 groundtruth, 
-                 segimage = None, 
-                 thresholdscore = 1 -  1.0E-4,  
-                 thresholdspace = 20, 
-                 thresholdtime = 4, 
-                 metric = 'Euclid',
-                 ignorez= False):
+    def __init__(self, 
+                 predictions: str, 
+                 groundtruth: str, 
+                 segimage: np.ndarray = None, 
+                 thresholdscore: float = 1 -  1.0E-4,  
+                 thresholdspace: int = 20, 
+                 thresholdtime: int = 4, 
+                 metric: str = 'Euclid',
+                 ignorez: bool = False):
 
          #A list of all the prediction csv files, path object
          self.predictions = list(Path(predictions).glob('*.csv')) 
@@ -163,8 +164,10 @@ class ClassificationScore:
                 nearest_location = (int(indices[nearest_location][0]), int(indices[nearest_location][1]), int(indices[nearest_location][2]))
                 self.location_gt.append([T_gt, nearest_location[0], nearest_location[1], nearest_location[2]])
               else:
-                self.location_gt.append([int(row[0]),int(row[1]),int(row[2]),int(row[3])])  
-         
+                self.location_gt.append([int(row[0]),int(row[1]),int(row[2]),int(row[3])]) 
+                 
+         gt_dataframe = pd.DataFrame(self.location_gt)
+         gt_dataframe.to_csv(str(self.csv_pred.parent) + '_GT_Accuracy' + '.csv')
 
          for csv_pred in self.predictions:
             self.location_pred = []
@@ -192,8 +195,10 @@ class ClassificationScore:
             GT.append(gt)
             Pred.append(pred)
          data = list(zip(Name, TP, FP, FN, Pred, GT))
-
+         data = sorted(data, key = lambda x: x[-2])
+         
          df = pd.DataFrame(data, columns=columns)
+         
          df.to_csv(str(self.csv_pred.parent) + '_Model_Accuracy' + '.csv')
          print(df)
          return df
